/**
 * Created by jmoutard on 19/07/16.
 */

'use strict';

angular.module('adf.electre')
    .service('storeService', [
        "$q", "serverStorageService", "localStorageService", "loggedIn",
        function ($q, serverStorageService, localStorageService, loggedIn) {
            loggedIn = false;
            /**
             * @description Return all dashboard stored in local browser or on server.
             * @returns {Promise}
             */
            function getAll () {
                var deferred = $q.defer();

                if (loggedIn)
                    serverStorageService.getAll().then(function (value) {
                        deferred.resolve(value);
                    }, function (error) {
                        deferred.reject(error);
                    });
                else
                    localStorageService.getAll().then(function (value) {
                        deferred.resolve(value);
                    }, function (error) {
                        deferred.reject(error);
                    });

                return deferred.promise;
            }

            /**
             * @description Return a specific stored dashboard from the server.
             * @param {string} id
             * @param {boolean|undefined} remote Tells if it's a server dashboard or a local dashboard (false - or undefined - by default which corresponds to local dashboard)
             * @returns {Promise}
             */
            function get (id, remote) {
                var deferred = $q.defer();

                if (remote)
                    serverStorageService.get(id)
                        .then(function (value) {
                            deferred.resolve(value);
                        }, function (error) {
                            deferred.reject(error);
                        });
                else
                    localStorageService.get(id)
                        .then(function (value) {
                            deferred.resolve(value);
                        }, function (error) {
                            deferred.reject(error);
                        });

                return deferred.promise;
            }

            /**
             * @description Add a dashboard onto the server.
             * @param {string} id
             * @param {object} data
             * @param {boolean|undefined} remote Tells if it's a server dashboard or a local dashboard (false - or undefined - by default which corresponds to local dashboard)
             * @returns {Promise}
             */
            function add (id, data, remote) {
                var deferred = $q.defer();

                if (remote)
                    serverStorageService.add(id, data).then(function (value) {
                        deferred.resolve(value);
                    }, function (error) {
                        deferred.reject(error);
                    });
                else
                    localStorageService.add(id, data).then(function (value) {
                        deferred.resolve(value);
                    }, function (error) {
                        deferred.reject(error);
                    });

                return deferred.promise;
            }

            /**
             * @description Remove a dashboard onto the server.
             * @param {string} id
             * @param {boolean|undefined} remote Tells if it's a server dashboard or a local dashboard (false - or undefined - by default which corresponds to local dashboard)
             * @returns {Promise}
             */
            function remove (id, remote) {
                var deferred = $q.defer();

                if (remote)
                    serverStorageService.remove(id).then(function (value) {
                        deferred.resolve(value);
                    }, function (error) {
                        deferred.reject(error);
                    });
                else
                    localStorageService.remove(id).then(function (value) {
                        deferred.resolve(value);
                    }, function (error) {
                        deferred.reject(error);
                    });

                return deferred.promise;
            }

            return { getAll: getAll, get: get, add: add, remove: remove};
        }
    ]);